@@ -3,7 +3,7 @@
  * XVID MPEG-4 VIDEO CODEC
  * - XviD Main header file -
  *
- *  Copyright(C) 2001-2003 Peter Ross <pross@xvid.org>
+ *  Copyright(C) 2001-2004 Peter Ross <pross@xvid.org>
  *
  *  This program is free software ; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -19,7 +19,7 @@
  *  along with this program ; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
  *
- * $Id$
+ * $Id: xvid.h,v 1.63.2.3 2009/05/25 08:09:23 Isibaar Exp $
  *
  ****************************************************************************/
 
@@ -57,8 +57,8 @@ extern "C" {
 #define XVID_API_MAJOR(a)        (((a)>>16) & 0xff)
 #define XVID_API_MINOR(a)        (((a)>> 0) & 0xff)
 
-#define XVID_VERSION             XVID_MAKE_VERSION(1,0,3)
-#define XVID_API                 XVID_MAKE_API(4, 0)
+#define XVID_VERSION             XVID_MAKE_VERSION(1,2,2)
+#define XVID_API                 XVID_MAKE_API(4, 2)
 
 /* Bitstream Version
  * this will be writen into the bitstream to allow easy detection of xvid
@@ -71,7 +71,7 @@ extern "C" {
  * doesnt hurt but not increasing it could cause difficulty for decoders in the
  * future
  */
-#define XVID_BS_VERSION 37
+#define XVID_BS_VERSION 50 
 
 /*****************************************************************************
  * error codes
@@ -100,6 +100,7 @@ extern "C" {
 #define XVID_CSP_YUY2     (1<< 3) /* 4:2:2 packed */
 #define XVID_CSP_UYVY     (1<< 4) /* 4:2:2 packed */
 #define XVID_CSP_YVYU     (1<< 5) /* 4:2:2 packed */
+#define XVID_CSP_RGB      (1<<16) /* 24-bit rgb packed */
 #define XVID_CSP_BGRA     (1<< 6) /* 32-bit bgra packed */
 #define XVID_CSP_ABGR     (1<< 7) /* 32-bit abgr packed */
 #define XVID_CSP_RGBA     (1<< 8) /* 32-bit rgba packed */
@@ -167,6 +168,8 @@ typedef struct {
 #define XVID_CPU_MMXEXT   (1<< 1) /*   mmx-ext : pentium2, athlon */
 #define XVID_CPU_SSE      (1<< 2) /*       sse : pentium3, athlonXP */
 #define XVID_CPU_SSE2     (1<< 3) /*      sse2 : pentium4, athlon64 */
+#define XVID_CPU_SSE3     (1<< 8) /*      sse3 : pentium4, athlon64 */
+#define XVID_CPU_SSE41    (1<< 9) /*      sse41: penryn */
 #define XVID_CPU_3DNOW    (1<< 4) /*     3dnow : k6-2 */
 #define XVID_CPU_3DNOWEXT (1<< 5) /* 3dnow-ext : athlon */
 #define XVID_CPU_TSC      (1<< 6) /*       tsc : Pentium */
@@ -248,6 +251,12 @@ typedef struct {
 #define XVID_DEBLOCKY      (1<<2) /* perform luma deblocking */
 #define XVID_DEBLOCKUV     (1<<3) /* perform chroma deblocking */
 #define XVID_FILMEFFECT    (1<<4) /* adds film grain */
+#define XVID_DERINGUV      (1<<5) /* perform chroma deringing, requires deblocking to work */
+#define XVID_DERINGY       (1<<6) /* perform luma deringing, requires deblocking to work */
+
+#define XVID_DEC_FAST      (1<<29) /* disable postprocessing to decrease cpu usage *todo* */
+#define XVID_DEC_DROP      (1<<30) /* drop bframes to decrease cpu usage *todo* */
+#define XVID_DEC_PREROLL   (1<<31) /* decode as fast as you can, don't even show output *todo* */
 
 typedef struct {
 	int version;
@@ -255,6 +264,8 @@ typedef struct {
 	void *bitstream;     /* [in]     bitstream (read from)*/
 	int length;          /* [in]     bitstream length */
 	xvid_image_t output; /* [in]     output image (written to) */
+/* ------- v1.1.x ------- */
+	int brightness;		 /* [in]	 brightness offset (0=none) */
 } xvid_dec_frame_t;
 
 
@@ -351,6 +362,7 @@ typedef struct {
 #define XVID_REQORIGINAL (1<<0) /* plugin requires a copy of the original (uncompressed) image */
 #define XVID_REQPSNR     (1<<1) /* plugin requires psnr between the uncompressed and compressed image*/
 #define XVID_REQDQUANTS  (1<<2) /* plugin requires access to the dquant table */
+#define XVID_REQLAMBDA   (1<<3) /* plugin requires access to the lambda table */
 
 
 typedef struct
@@ -416,6 +428,9 @@ typedef struct
 	int vol_flags;          /* [in,out] */
 	int motion_flags;       /* [in,out] */
 
+	/* Lambda table for HVSPlugins */
+	float * lambda;         /* [in,out] six floats for each macroblock. read, multiply, write back */
+
 /* Deprecated, use the stats field instead.
  * Will disapear before 1.0 */
 	int length;             /* [out] after: length of encoded frame */
@@ -471,6 +486,8 @@ extern xvid_plugin_func xvid_plugin_lumimasking;  /* lumimasking */
 extern xvid_plugin_func xvid_plugin_psnr;	/* write psnr values to stdout */
 extern xvid_plugin_func xvid_plugin_dump;	/* dump before and after yuvpgms */
 
+extern xvid_plugin_func xvid_plugin_ssim;	/*write ssim values to stdout*/
+
 
 /* single pass rate control
  * CBR and Constant quantizer modes */
@@ -498,7 +515,7 @@ typedef struct {
 typedef struct {
 	int version;
 
-	int bitrate;                  /* [in] bits per second */
+	int bitrate;                  /* [in] target bitrate (bits per second) */
 	char * filename;              /* [in] first pass stats filename */
 
 	int keyframe_boost;           /* [in] keyframe boost percentage: [0..100] */
@@ -515,8 +532,31 @@ typedef struct {
 								   *      0 for 1<distance<kfthreshold */
 
 	int container_frame_overhead; /* [in] How many bytes the controller has to compensate per frame due to container format overhead */
+
+/* ------- v1.1.x ------- */
+	int vbv_size;                 /* [in] buffer size (bits) */
+	int vbv_initial;              /* [in] initial buffer occupancy (bits) */
+	int vbv_maxrate;              /* [in] max processing bitrate (bits per second) */
+	int vbv_peakrate;             /* [in:opt] max average bitrate over 3 seconds (bits per second) */
+
 }xvid_plugin_2pass2_t;
 
+
+typedef struct{
+	/*stat output*/
+	int b_printstat;
+	char* stat_path;
+	
+	/*visualize*/
+	int b_visualize;
+
+	/*accuracy 0 very accurate 4 very fast*/
+	int acc; 
+
+    int cpu_flags; /* XVID_CPU_XXX flags */
+
+} xvid_plugin_ssim_t;
+
 /*****************************************************************************
  *                             ENCODER API
  ****************************************************************************/
@@ -576,7 +616,8 @@ extern int xvid_encore(void *handle, int opt, void *param1, void *param2);
 #define XVID_GLOBAL_VOL_AT_IVOP       (1<<3) /* write vol at every ivop: WIN32/divx compatibility */
 #define XVID_GLOBAL_FORCE_VOL         (1<<4) /* when vol-based parameters are changed, insert an ivop NOT recommended */
 #endif
-
+#define XVID_GLOBAL_DIVX5_USERDATA    (1<<5) /* write divx5 userdata string 
+                                                this is implied if XVID_GLOBAL_PACKED is set */
 
 /*----------------------------------------------------------------------------
  * "VOL" flags
@@ -590,6 +631,7 @@ extern int xvid_encore(void *handle, int opt, void *param1, void *param2);
 #define XVID_VOL_QUARTERPEL     (1<<2) /* enable quarterpel: frames will encoded as quarterpel */
 #define XVID_VOL_GMC            (1<<3) /* enable GMC; frames will be checked for gmc suitability */
 #define XVID_VOL_REDUCED_ENABLE (1<<4) /* enable reduced resolution vops: frames will be checked for rrv suitability */
+									   /* NOTE:  the reduced resolution feature is not supported anymore. This flag will have no effect! */
 #define XVID_VOL_INTERLACING    (1<<5) /* enable interlaced encoding */
 
 
@@ -611,6 +653,7 @@ extern int xvid_encore(void *handle, int opt, void *param1, void *param2);
 #define XVID_VOP_HQACPRED             (1<< 7) /* high quality ac prediction */
 #define XVID_VOP_MODEDECISION_RD      (1<< 8) /* enable DCT-ME and use it for mode decision */
 #define XVID_VOP_FAST_MODEDECISION_RD (1<<12) /* use simplified R-D mode decision */
+#define XVID_VOP_RD_BVOP              (1<<13) /* enable rate-distortion mode decision in b-frames */
 
 /* Only valid for vol_flags|=XVID_VOL_INTERLACING */
 #define XVID_VOP_TOPFIELDFIRST        (1<< 9) /* set top-field-first flag  */
@@ -618,7 +661,7 @@ extern int xvid_encore(void *handle, int opt, void *param1, void *param2);
 
 /* only valid for vol_flags|=XVID_VOL_REDUCED_ENABLED */
 #define XVID_VOP_REDUCED              (1<<11) /* reduced resolution vop */
-
+											  /* NOTE: reduced resolution feature is not supported anymore. This flag will have no effect! */
 
 /*----------------------------------------------------------------------------
  * "Motion" flags
